@@ -165,10 +165,10 @@ class BaseCachingTable(BaseTable):
         pending_remove_operations[joined_field_path] = field_path_elements
 
     def _cache_process_add_delete_operation(self, index_cached_data: dict, pending_remove_operations: dict, field_path: str, query_kwargs: Optional[dict] = None):
-        target_field_container, has_multiple_fields_path = process_and_make_single_rendered_database_path(
+        target_field_container, is_multi_selector = process_and_make_single_rendered_database_path(
             field_path=field_path, fields_switch=self.fields_switch, query_kwargs=query_kwargs
         )
-        if has_multiple_fields_path is not True:
+        if is_multi_selector is not True:
             target_field_container: Tuple[BaseField, List[DatabasePathElement]]
             field_object, field_path_elements = target_field_container
 
@@ -294,15 +294,15 @@ class BaseCachingTable(BaseTable):
         )
 
     def _get_field(
-            self, middleware: Callable[[List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], bool], Any],
+            self, middleware: Callable[[Union[List[DatabasePathElement], Dict[str, List[DatabasePathElement]]], bool], Any],
             key_value: str, field_path: str, query_kwargs: Optional[dict], data_validation: bool
     ) -> Optional[Any]:
 
         index_cached_data: dict = self._index_cached_data(primary_key_value=key_value)
-        target_field_container, has_multiple_fields_path = process_and_make_single_rendered_database_path(
+        target_field_container, is_multi_selector = process_and_make_single_rendered_database_path(
             field_path=field_path, fields_switch=self.fields_switch, query_kwargs=query_kwargs
         )
-        if has_multiple_fields_path is not True:
+        if is_multi_selector is not True:
             target_field_container: Tuple[BaseField, List[DatabasePathElement]]
             field_object, field_path_elements = target_field_container
 
@@ -358,9 +358,9 @@ class BaseCachingTable(BaseTable):
             return output_items
 
     def inner_query_fields_secondary_index(
-            self, middleware: Callable[[List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], bool], Any],
+            self, middleware: Callable[[Union[List[DatabasePathElement], Dict[str, List[DatabasePathElement]]], bool], Any],
             target_field_container: Union[Tuple[BaseField, List[DatabasePathElement]], Dict[str, Tuple[BaseField, List[DatabasePathElement]]]],
-            has_multiple_fields_path: bool, data_validation: bool
+            is_multi_selector: bool, data_validation: bool
     ) -> Optional[dict]:
         from StructNoSQL.tables.shared_table_behaviors import _inner_query_fields_secondary_index
         return _inner_query_fields_secondary_index(
@@ -371,11 +371,11 @@ class BaseCachingTable(BaseTable):
             get_primary_key_database_path=self._get_primary_key_database_path,
             middleware=middleware,
             target_field_container=target_field_container,
-            has_multiple_fields_path=has_multiple_fields_path
+            is_multi_selector=is_multi_selector
         )
 
     def _shared_rar(
-            self, middleware: Callable[[List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], bool], List[Any]],
+            self, middleware: Callable[[Union[List[DatabasePathElement], Dict[str, List[DatabasePathElement]]], bool], List[Any]],
             key_value: str, target_fields_containers: Dict[str, Tuple[BaseField, List[DatabasePathElement]]], data_validation: bool
     ):
         existing_record_data: dict = {}
@@ -415,11 +415,11 @@ class BaseCachingTable(BaseTable):
         return {key_value: existing_record_data}
 
     def _query_field(
-            self, middleware: Callable[[List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], bool], List[Any]],
+            self, middleware: Callable[[Union[List[DatabasePathElement], Dict[str, List[DatabasePathElement]]], bool], List[Any]],
             key_value: str, field_path: str, query_kwargs: Optional[dict], index_name: Optional[str], data_validation: bool
     ) -> Optional[dict]:
 
-        target_field_container, has_multiple_fields_path = process_and_make_single_rendered_database_path(
+        target_field_container, is_multi_selector = process_and_make_single_rendered_database_path(
             field_path=field_path, fields_switch=self.fields_switch, query_kwargs=query_kwargs
         )
         if index_name is not None and index_name != self.primary_index_name:
@@ -427,11 +427,11 @@ class BaseCachingTable(BaseTable):
                 middleware=middleware,
                 data_validation=data_validation,
                 target_field_container=target_field_container,
-                has_multiple_fields_path=has_multiple_fields_path
+                is_multi_selector=is_multi_selector
             )
         else:
             # If requested index is primary index
-            if has_multiple_fields_path is not True:
+            if is_multi_selector is not True:
                 target_field_container: Tuple[BaseField, List[DatabasePathElement]]
                 field_object, field_path_elements = target_field_container
 
@@ -448,7 +448,7 @@ class BaseCachingTable(BaseTable):
                         {'value': field_value_from_cache, 'fromCache': True}
                     )}
 
-                retrieved_records_items_data: Optional[List[Any]] = middleware(field_path_elements, has_multiple_fields_path)
+                retrieved_records_items_data: Optional[List[Any]] = middleware(field_path_elements, is_multi_selector)
                 if retrieved_records_items_data is not None and len(retrieved_records_items_data) > 0:
                     # Since we query the primary_index, we know for a fact that we will never be returned more than
                     # one record item. Hence why we do not have a loop that iterate over the records_items_data,
@@ -498,7 +498,7 @@ class BaseCachingTable(BaseTable):
                 middleware=middleware,
                 data_validation=data_validation,
                 target_field_container=single_getters_target_fields_containers,
-                has_multiple_fields_path=True
+                is_multi_selector=True
             )
 
     def _unpack_getters_response_item(
@@ -542,10 +542,10 @@ class BaseCachingTable(BaseTable):
 
         getters_database_paths: List[List[DatabasePathElement]] = []
         for getter_key, getter_item in getters.items():
-            target_field_container, has_multiple_fields_path = process_and_make_single_rendered_database_path(
+            target_field_container, is_multi_selector = process_and_make_single_rendered_database_path(
                 field_path=getter_item.field_path, fields_switch=self.fields_switch, query_kwargs=getter_item.query_kwargs
             )
-            if has_multiple_fields_path is not True:
+            if is_multi_selector is not True:
                 target_field_container: Tuple[BaseField, List[DatabasePathElement]]
                 field_object, field_path_elements = target_field_container
 
@@ -684,7 +684,7 @@ class BaseCachingTable(BaseTable):
                     )
             elif isinstance(current_setter, UnsafeFieldSetter):
                 raise Exception(f"UnsafeFieldSetter not supported in caching_table")
-                """safe_field_path_object, has_multiple_fields_path = process_and_get_field_path_object_from_field_path(
+                """safe_field_path_object, is_multi_selector = process_and_get_field_path_object_from_field_path(
                     field_path_key=current_setter.safe_base_field_path, fields_switch=self.fields_switch
                 )
                 # todo: add support for multiple fields path
@@ -782,12 +782,12 @@ class BaseCachingTable(BaseTable):
             key_value: str, field_path: str, query_kwargs: Optional[dict], data_validation: bool
     ) -> Optional[Any]:
 
-        target_field_container, has_multiple_fields_path = process_and_make_single_rendered_database_path(
+        target_field_container, is_multi_selector = process_and_make_single_rendered_database_path(
             field_path=field_path, fields_switch=self.fields_switch, query_kwargs=query_kwargs
         )
         index_cached_data = self._index_cached_data(primary_key_value=key_value)
 
-        if has_multiple_fields_path is not True:
+        if is_multi_selector is not True:
             target_field_container: Tuple[BaseField, List[DatabasePathElement]]
             field_object, field_path_elements = target_field_container
 
@@ -844,7 +844,7 @@ class BaseCachingTable(BaseTable):
                         field_path_elements=item_field_path_elements
                     )
                     container_output_data[item_key] = self._validate_format_field_value_if_need_to(
-                        value=found_item_value_in_cache, data_validation=data_validation,
+                        value=field_item_value_from_cache, data_validation=data_validation,
                         field_object=item_field_object, from_cache=True
                     )
                 else:
@@ -901,11 +901,11 @@ class BaseCachingTable(BaseTable):
 
             removers_database_paths: List[List[DatabasePathElement]] = []
             for remover_key, remover_item in removers.items():
-                target_field_container, has_multiple_fields_path = process_and_make_single_rendered_database_path(
+                target_field_container, is_multi_selector = process_and_make_single_rendered_database_path(
                     field_path=remover_item.field_path, fields_switch=self.fields_switch,
                     query_kwargs=remover_item.query_kwargs
                 )
-                if has_multiple_fields_path is not True:
+                if is_multi_selector is not True:
                     target_field_container: Tuple[BaseField, List[DatabasePathElement]]
                     field_object, field_path_elements = target_field_container
 
